/*
  OS Pixie MK2 Enclosure Base

  Drawn by Mike Kitchen (Mike_K on mode-zero.uk)
  There are separate files for the enclosure, enclosure base, lid and switch

  The main enclosure is made in two parts and the parts are glued together. This means they can be made with little or no supports.
  The lid is held on with small magnets so no central pillar is needed and the thumb screw is for appearance only and is non-functional (it is glued into position)

  1. module side()
        a. construct the side outline with cylinders with spheres on top
        b. draw the other side using mirror
  2. Use "hull()" to get the basic shape
  3. Repeat the above with reduced dimensions to make a step on the bottom to fit the main enclosure
  4. Add the small ribs to to top (what will be the bottom of the completed item)
*/


$fn = 80; //Render a bit quicker (not smoother!)

difference() {
  union() { //To remove bits from the enclosure

    translate ([0, 0, 2]) {
      hull() { //make a smooth shape around the enclosure
        side(0);

        mirror() {  //Draw the other side of the enclosure
          side(0);

        }
      }
    }
    hull() { //make a smooth shape around the enclosure
      side(2.2);

      mirror() {  //Draw the other side of the enclosure
        side(2.2);

      }
    }

    //Add the raised ridges to the face of the lid (will be on the bottom)

    translate ([0, 11, 9]) {
      cube ([59.7, 1, 0.5], center = true);
    }
    translate ([29.85, 11, 5.75]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.5, h = 1, center = true);
      }
    }
    translate ([-29.85, 11, 5.75]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.5, h = 1, center = true);
      }
    }
    translate ([0, 19, 9]) {
      cube ([59.7, 1, 0.5], center = true);
    }
    translate ([29.85, 19, 5.75]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.5, h = 1, center = true);
      }
    }
    translate ([-29.85, 19, 5.75]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.5, h = 1, center = true);
      }
    }
    translate ([0, 27, 9]) {
      cube ([59.7, 1, 0.5], center = true);
    }
    translate ([29.85, 27, 5.75]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.5, h = 1, center = true);
      }
    }
    translate ([-29.85, 27, 5.75]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.5, h = 1, center = true);
      }
    }
    translate ([0, -45.5, 9]) {
      cube ([51.7, 1, 0.5], center = true);
    }
    translate ([25.3, -45.5, 5.82]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.44, h = 1, center = true);
      }
    }
    translate ([-25.3, -45.5, 5.82]) {
      rotate(a = [90, 90, 0]) {
        cylinder (r = 3.44, h = 1, center = true);
      }
    }
    translate ([0, -40, 9]) { //
      linear_extrude(height = .5, center = true) {
        text("Made in UK", font = "Arial:style=Bold", size = 2, halign = "center", valign = "center", center = true);
      }
    }
  }
  hull() { //make a smooth shape around the enclosure
    side(5);

    mirror() {  //Draw the other side of the enclosure
      side(5);

    }
  }
}

/*The Pixie MK2 transmitter widths from the top to the bottom
  in 10mm steps. The bottom (last) dimension is 12mm
  as case is 112mm tall (length)
*/

module side(wallThick) { //module to draw a side. Its used to draw both sides

  //Dimensions of enclosure width /2 (half width)
  /*
    w0 = 33; //66
    w1 = 33.25; //66.5
    w2 = 33.5; //67
    w3 = 33.5; //67
    w4 = 33.5; //67
    w5 = 33.25; //66.5
    w6 = 32.75; //65.5
    w7 = 32.25; //64.5
    w8 = 31.25; //62.5
    w9 = 30; //60
    w10 = 29; //58
    w11 = 28; //56
  */
  enclosureWidth = [33, 33.25, 33.5, 33.5, 33.5, 33.25, 32.75, 32.25, 31.25, 30, 29, 28];

  length = 112; //top to bottom
  height = 7; //without lid
  r1 = 5; //corner radius top and bottom
  r2 = 3; //corner radius around the face

  union() { //All the bits to add to the side

    //top width dimension
    translate ([r1 + wallThick - enclosureWidth[0], (length / 2) - wallThick - r1, (height - r2) / 2]) {
      cylinder (r = r1, h = (height - r2), center = true);
    }

    //Extrude the sphere radius r2 (3mm) around the corner radius r1 (5mm)
    translate ([r1 + wallThick - enclosureWidth[0], (length / 2) - wallThick - r1, (height - r2)]) {
      rotate_extrude(convexity = 10)
      translate([2, 0, 0])
      difference() {
        circle(r = 3);
        polygon( points = [[0, -3], [-3, -3], [-3, 3], [0, 3]] );
      }
    }

    for (i = [1:10]) { //for the 10 widths between the top and bottom
      //echo(enclosureWidth[i]);
      translate ([r1 + wallThick - enclosureWidth[i], (length / 2) - (i * 10), (height - r2) / 2]) {
        cylinder (r = r1, h = (height - r2), center = true);
      }
      translate ([r2 + wallThick - enclosureWidth[i], (length / 2) - (i * 10), (height - r2)]) {
        sphere(r = r2, center = true);
      }
    }


    //bottom width dimension.
    translate ([r1 + wallThick - enclosureWidth[11], (length / 2) - 112 + 5 + wallThick, (height - r2) / 2]) {
      cylinder (r = r1, h = (height - r2), center = true);
    }
    //Extrude the sphere radius r2 (3mm) around the corner radius r1 (5mm)
    translate ([r1 + wallThick - enclosureWidth[11], (length / 2) - 112 + 5 + wallThick, (height - r2)]) {
      rotate_extrude(convexity = 10)
      translate([2, 0, 0])
      difference() {
        circle(r = 3);
        polygon( points = [[0, -3], [-3, -3], [-3, 3], [0, 3]] );
      }
    }
  }
}
